@@ -124,6 +124,43 @@ class TembaClientTest(TembaTest):
         self.assertRaises(TembaRateExceededError, self.client.get_runs().all, retry_on_rate_exceed=False)
         self.assertRaises(TembaRateExceededError, self.client.get_runs().all, retry_on_rate_exceed=True)
 
+    def test_query_with_transformer(self, mock_request):
+        mock_request.return_value = MockResponse(200, """{
+    "next": null,
+    "previous": null,
+    "results": [
+        {
+            "key": "chat_name",
+            "label": "Chat Name",
+            "value_type": "text"
+        },
+        {
+            "key": "age",
+            "label": "Age",
+            "value_type": "numeric"
+        }
+    ]
+}""")
+        def convert_old_fields(clazz, item):
+            if clazz == Field:
+                item["name"] = item["label"]
+                item["type"] = "number" if item["value_type"] == "numeric" else item["value_type"]
+            return item
+
+        client = TembaClient("example.com", "1234567890", user_agent="test/0.1", transformer=convert_old_fields)                                               
+
+        results = client.get_fields().all()
+
+        self.assertRequest(mock_request, "get", "fields")
+        self.assertEqual(len(results), 2)
+
+        self.assertEqual(results[0].key, "chat_name")
+        self.assertEqual(results[0].name, "Chat Name")
+        self.assertEqual(results[0].type, "text")
+        self.assertEqual(results[1].key, "age")
+        self.assertEqual(results[1].name, "Age")
+        self.assertEqual(results[1].type, "number")
+
     # ==================================================================================================================
     # Fetch object operations
     # ==================================================================================================================
@@ -881,9 +918,9 @@ class TembaClientTest(TembaTest):
 
     def test_create_field(self, mock_request):
         mock_request.return_value = MockResponse(201, self.read_json("fields", extract_result=0))
-        field = self.client.create_field(label="Chat Name", value_type="text")
+        field = self.client.create_field(name="Chat Name", type="text")
 
-        self.assertRequest(mock_request, "post", "fields", data={"label": "Chat Name", "value_type": "text"})
+        self.assertRequest(mock_request, "post", "fields", data={"name": "Chat Name", "type": "text"})
         self.assertEqual(field.key, "chat_name")
 
     def test_create_flow_start(self, mock_request):
@@ -1047,28 +1084,28 @@ class TembaClientTest(TembaTest):
         mock_request.return_value = MockResponse(201, self.read_json("fields", extract_result=0))
 
         # check update by object
-        field = self.client.update_field(Field.create(key="chat_name"), label="Chat Name", value_type="text")
+        field = self.client.update_field(Field.create(key="chat_name"), name="Chat Name", type="text")
 
         self.assertRequest(
             mock_request,
             "post",
             "fields",
             params={"key": "chat_name"},
-            data={"label": "Chat Name", "value_type": "text"},
+            data={"name": "Chat Name", "type": "text"},
         )
         self.assertEqual(field.key, "chat_name")
 
         mock_request.return_value = MockResponse(404, {"detail": "Not found."})
 
         with self.assertRaises(TembaNoSuchObjectError):
-            self.client.update_field(Field.create(key="chat_name2"), label="Chat Name", value_type="text")
+            self.client.update_field(Field.create(key="chat_name2"), name="Chat Name", type="text")
 
             self.assertRequest(
                 mock_request,
                 "post",
                 "fields",
                 params={"key": "chat_name"},
-                data={"label": "Chat Name", "value_type": "text"},
+                data={"name": "Chat Name", "type": "text"},
             )
 
     def test_update_global(self, mock_request):
